.. :DataFile:

Data File
=========

.. currentmodule:: Data.DataFile



.. autosummary::
   :nosignatures:

    DataFile.DataFile
	DataFile.DataFile.difference
	DataFile.DataFile.loadBinning
	DataFile.DataFile.loadMultiFLEXXData
	DataFile.DataFile.plotA4
	DataFile.DataFile.plotEf
	DataFile.DataFile.plotEfOverview
	DataFile.DataFile.plotNormalization
	DataFile.DataFile.saveNXsqom
	DataFile.createEmptyDataFile


DataFile Object and Methods
---------------------------


.. automodule:: DataFile

.. _DataFile:

.. autoclass:: DataFile
    :members:

.. autofunction:: DataFile.createEmptyDataFile
